@@ -8,7 +8,7 @@ package Build::Hopen::Base;
 use parent 'Exporter';
 use Import::Into;
 
-our $VERSION = '0.000003'; # TRIAL
+our $VERSION = '0.000004'; # TRIAL
 
 # Pragmas
 use 5.014;
@@ -55,6 +55,21 @@ sub import {
     Data::Dumper->import::into($target);
     Carp->import::into($target, qw(carp croak confess));
 
+    # Permit smartmatch
+    warnings->unimport::out_of($target, 'experimental::smartmatch');
+
 } #import()
 
 1;
+__END__
+
+=head1 NAME
+
+Build::Hopen::Base - basic definitions for hopen
+
+=head1 SYNOPSIS
+
+C<use Build::Hopen::Base;> to pull in C<5.014>, L<strict>, L<warnings>,
+L<Carp>, L<Data::Dumper>, C<true>, and C<false>.
+
+=cut
